API docs for “spamfighter.core.commands.test.test_partner.PartneredCommandTestCase”

# Class s.c.c.t.t.PartneredCommandTestCase(unittest.TestCase):

Part of spamfighter.core.commands.test.test_partner View Source View In Hierarchy

Тест на `spamfighter.core.commands.partner.PartneredCommand`.

Method | setUp | Undocumented
Method | testAuthOK | Undocumented
Method | testAuthFail | Undocumented

def setUp(self): (source)
Undocumented
def testAuthOK(self): (source)
Undocumented
def testAuthFail(self): (source)
Undocumented